==> visualvm_1.3.8.orig.tar.xz: visualvm-1.3.8/netbeans/profiler.api/src/org/netbeans/modules/profiler/api/ProgressDisplayer.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.profiler.api;

import org.netbeans.api.progress.ProgressHandle;
import org.netbeans.api.progress.ProgressHandleFactory;
import org.openide.util.Cancellable;

/**
 *
 * @author Jaroslav Bachorik
 */
public interface ProgressDisplayer {
    //~ Inner Interfaces ---------------------------------------------------------------------------------------------------------

    public static interface ProgressController extends Cancellable {
    }

    //~ Methods ------------------------------------------------------------------------------------------------------------------

    public void close();

    public ProgressDisplayer showProgress(String message);

    public ProgressDisplayer showProgress(String message, ProgressController controller);

    public ProgressDisplayer showProgress(String caption, String message, ProgressController controller);
    
    public static final ProgressDisplayer DEFAULT = new ProgressDisplayer() {
        ProgressHandle ph = null;

        public synchronized ProgressDisplayer showProgress(String message) {
            ph = ProgressHandleFactory.createHandle(message);
            ph.start();
            return DEFAULT;
        }

        public synchronized ProgressDisplayer showProgress(String message, ProgressController controller) {
            ph = ProgressHandleFactory.createHandle(message, controller);
            ph.start();
            return DEFAULT;
        }

        public synchronized ProgressDisplayer showProgress(String caption, String message, ProgressController controller) {
            ph = ProgressHandleFactory.createHandle(message, controller);
            ph.start();
            return DEFAULT;
        }

        public synchronized void close() {
            if (ph != null) {
                ph.finish();
                ph = null;
            }
        }
    };

}

==> visualvm_1.4.2.orig.tar.xz: visualvm-1.4.2/netbeans/profiler.api/src/org/netbeans/modules/profiler/api/ProgressDisplayer.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.profiler.api;

import org.netbeans.api.progress.ProgressHandle;
import org.openide.util.Cancellable;

/**
 *
 * @author Jaroslav Bachorik
 */
public interface ProgressDisplayer {
    //~ Inner Interfaces ---------------------------------------------------------------------------------------------------------

    public static interface ProgressController extends Cancellable {
    }

    //~ Methods ------------------------------------------------------------------------------------------------------------------

    public void close();

    public ProgressDisplayer showProgress(String message);

    public ProgressDisplayer showProgress(String message, ProgressController controller);

    public ProgressDisplayer showProgress(String caption, String message, ProgressController controller);
    
    public static final ProgressDisplayer DEFAULT = new ProgressDisplayer() {
        ProgressHandle ph = null;

        public synchronized ProgressDisplayer showProgress(String message) {
            ph = ProgressHandle.createHandle(message);
            ph.start();
            return DEFAULT;
        }

        public synchronized ProgressDisplayer showProgress(String message, ProgressController controller) {
            ph = ProgressHandle.createHandle(message, controller);
            ph.start();
            return DEFAULT;
        }

        public synchronized ProgressDisplayer showProgress(String caption, String message, ProgressController controller) {
            ph = ProgressHandle.createHandle(message, controller);
            ph.start();
            return DEFAULT;
        }

        public synchronized void close() {
            if (ph != null) {
                ph.finish();
                ph = null;
            }
        }
    };

}
